Struct amazon_sp_fba_small_and_light::models::small_and_light_enrollment::SmallAndLightEnrollment
source · [−]pub struct SmallAndLightEnrollment {
pub marketplace_id: String,
pub seller_sku: String,
pub status: SmallAndLightEnrollmentStatus,
}Expand description
SmallAndLightEnrollment : The Small and Light enrollment status of the item indicated by the specified seller SKU.
Fields
marketplace_id: StringA marketplace identifier.
seller_sku: StringIdentifies an item in the given marketplace. SellerSKU is qualified by the seller’s SellerId, which is included with every operation that you submit.
status: SmallAndLightEnrollmentStatusImplementations
sourceimpl SmallAndLightEnrollment
impl SmallAndLightEnrollment
sourcepub fn new(
marketplace_id: String,
seller_sku: String,
status: SmallAndLightEnrollmentStatus
) -> SmallAndLightEnrollment
pub fn new(
marketplace_id: String,
seller_sku: String,
status: SmallAndLightEnrollmentStatus
) -> SmallAndLightEnrollment
The Small and Light enrollment status of the item indicated by the specified seller SKU.